@@ -626,6 +626,11 @@ var app = new Vue({
 
         },
 
+        gotoPage: function ( page ) {
+            this.currentPage = page;
+            window.scrollTo( 0, 0 );
+        },
+
         fillUrl: function ( tmpl, data ) {
             return tmpl.replace( /\{([^}]+)\}/g, function ( match, field ) {
                 return data[field];
